@@ -31,6 +31,7 @@
 #include <kmime/kmime_message.h>
 
 #include <QDataStream>
+#include <QVector>
 
 class KConfigGroup;
 
@@ -91,7 +92,7 @@ public:
     */
     Q_REQUIRED_RESULT QString identifier() const;
 
-    /** Equivalent to @pattern()->name(). @return name of the filter */
+    /** Equivalent to @p pattern()->name(). @return name of the filter */
     Q_REQUIRED_RESULT QString name() const;
 
     /** Execute the filter action(s) on the given message.
@@ -101,9 +102,9 @@ public:
       the owner of the message,
       @li 0 if processed successfully.
       @param context The context that contains the item to which the actions should be applied.
-      @param stopIt Contains
-      true if the caller may apply other filters and false if he shall
+      @param stopIt Contains @c true if the caller may apply other filters and @c false if he shall
       stop the filtering of this message.
+      @param applyOnOutbound Defines whether to apply the rules on the outbound.
     */
     Q_REQUIRED_RESULT ReturnCode execActions(ItemContext &context, bool &stopIt, bool applyOnOutbound) const;
 
@@ -127,10 +128,10 @@ public:
     /** Provides a reference to the internal action list. If your used
       the @p setAction() and @p action() functions before, please
       convert to using myFilter->actions()->at() and friends now. */
-    QList<FilterAction *> *actions();
+    QVector<FilterAction *> *actions();
 
     /** Provides a reference to the internal action list. Const version. */
-    const QList<FilterAction *> *actions() const;
+    const QVector<FilterAction *> *actions() const;
 
     /** Provides a reference to the internal pattern. If you used the
       @p matches() function before, please convert to using
@@ -321,14 +322,14 @@ public:
     bool isEnabled() const;
     void setEnabled(bool);
 
-    void generateSieveScript(QStringList &requires, QString &code);
+    void generateSieveScript(QStringList &requiresModules, QString &code);
 
     void clearApplyOnAccount();
     void agentRemoved(const QString &identifier);
 private:
     QString mIdentifier;
     SearchPattern mPattern;
-    QList<FilterAction *> mActions;
+    QVector<FilterAction *> mActions;
     QStringList mAccounts;
     QString mIcon;
     QString mToolbarName;
